<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template normally located in the
 * modules/system folder.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $hide_site_name: TRUE if the site name has been toggled off on the theme
 *   settings page. If hidden, the "element-invisible" class is added to make
 *   the site name visually hidden, but still accessible.
 * - $hide_site_slogan: TRUE if the site slogan has been toggled off on the
 *   theme settings page. If hidden, the "element-invisible" class is added to
 *   make the site slogan visually hidden, but still accessible.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 */
?>

  <nav class="navbar navbar-default navbar-static-top">
    <div class="container">
	  <div class="row">
	    <div class="col-xs-12 nopadding">
		
		  <div class="navbar-header">
		    <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar-main" aria-expanded="false">
		      <span class="icon-bar"></span>
			  <span class="icon-bar"></span>
		      <span class="icon-bar"></span>
			</button>
			  
			<?php if ($logo): ?>
			  <div id="logo">
			    <?php if($is_front): ?>
				  <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
				  <h1 id="sitename">
					<?php print $site_name; ?>
				  </h1>
				<?php else: ?>
				  <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" /></a>
				  <h1 id="sitename">
					<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>"><?php print $site_name; ?></a>
				  </h1>
				<?php endif; ?>
			  </div>
			<?php endif; ?>
		  </div>

  		  <div class="collapse navbar-collapse" id="navbar-main">
		    <?php 
		      $main_menu_tree = menu_tree(variable_get('menu_main_links_source', 'main-menu'));
		      print drupal_render($main_menu_tree);	 
		    ?>				 
		  </div>
		</div>
	  </div>
    </div>
  </nav>

  
  <?php if ($is_front): ?>
    <?php if (theme_get_setting('slideshow_display','likable')): ?>
      <?php 
        $slide1_head = check_plain(theme_get_setting('slide1_head','likable'));   $slide1_desc = check_markup(theme_get_setting('slide1_desc','likable'), 'full_html'); $slide1_url = check_plain(theme_get_setting('slide1_url','likable'));
        $slide2_head = check_plain(theme_get_setting('slide2_head','likable'));   $slide2_desc = check_markup(theme_get_setting('slide2_desc','likable'), 'full_html'); $slide2_url = check_plain(theme_get_setting('slide2_url','likable'));
        $slide3_head = check_plain(theme_get_setting('slide3_head','likable'));   $slide3_desc = check_markup(theme_get_setting('slide3_desc','likable'), 'full_html'); $slide3_url = check_plain(theme_get_setting('slide3_url','likable'));
      ?>
      <div id="slidebox" class="flexslider">
        <ul class="slides">
          <li>
            <img src="<?php print base_path() . drupal_get_path('theme', 'likable') . '/images/slide-1.jpg'; ?>"/>
            <?php if($slide1_head || $slide1_desc) : ?>
              <div class="flex-caption">
                <h2><?php print $slide1_head; ?></h2><?php print $slide1_desc; ?>
                <a class="readmore" href="<?php print url($slide1_url); ?>"> <?php print t('READ MORE'); ?> </a>
              </div>
            <?php endif; ?>
          </li>
          <li>
            <img src="<?php print base_path() . drupal_get_path('theme', 'likable') . '/images/slide-2.jpg'; ?>"/>
            <?php if($slide2_head || $slide2_desc) : ?>
              <div class="flex-caption">
                <h2><?php print $slide2_head; ?></h2><?php print $slide2_desc; ?>
                <a class="readmore" href="<?php print url($slide2_url); ?>"> <?php print t('READ MORE'); ?> </a>
              </div>
            <?php endif; ?>
          </li>
          <li>
            <img src="<?php print base_path() . drupal_get_path('theme', 'likable') . '/images/slide-3.jpg'; ?>"/>
            <?php if($slide3_head || $slide3_desc) : ?>
              <div class="flex-caption">
                <h2><?php print $slide3_head; ?></h2><?php print $slide3_desc; ?>
                <a class="readmore" href="<?php print url($slide3_url); ?>"> <?php print t('READ MORE'); ?> </a>
              </div>
            <?php endif; ?>
          </li>
        </ul>
        <div class="overlay"></div>
      </div>
    <?php endif; ?>
  <?php endif; ?>
  
  
  <?php if($page['header']) : ?>
    <header>
      <div class="container">
        <div class="row">
          <div class="col-sm-12">
            <?php print render($page['header']); ?>
          </div>
        </div>
      </div>
    </header>
  <?php endif; ?>
  
  
  <?php if($page['top_first'] || $page['top_second'] || $page['top_third'] || $page['top_fourth']): ?>
    <?php $top_col = ( 12 / ( (bool) $page['top_first'] + (bool) $page['top_second'] + (bool) $page['top_third'] + (bool) $page['top_fourth'] ) ); ?>
    <div id="top-columns">
	  <div class="container">
	    <div class="row">
	      <?php if($page['top_first']): ?>
		    <div class="col-xs-12 col-sm-<?php print $top_col; ?>">
		      <?php print render($page['top_first']); ?>
		    </div>
		  <?php endif; ?>
		  <?php if($page['top_second']): ?>
		    <div class="col-xs-12 col-sm-<?php print $top_col; ?>">
		      <?php print render($page['top_second']); ?>
		    </div>
		  <?php endif; ?>
	      <?php if($page['top_third']): ?>
		    <div class="col-xs-12 col-sm-<?php print $top_col; ?>">
		      <?php print render($page['top_third']); ?>
		    </div>
		  <?php endif; ?>
	      <?php if($page['top_fourth']): ?>
		    <div class="col-xs-12 col-sm-<?php print $top_col; ?>">
		      <?php print render($page['top_fourth']); ?>
		    </div>
		  <?php endif; ?>
	    </div>
	  </div>
    </div>
  <?php endif; ?>

  
  <div id="main">
    <div class="container"> 
      <div class="row">
				
        <?php 
	      if($page['sidebar_first'] && $page['sidebar_second']): 
		    $main_col = 6; 
		  elseif($page['sidebar_first'] || $page['sidebar_second']): 
		    $main_col = 9; 
		  else: 
		    $main_col = 12; 
	      endif; 
	    ?>
			
		<?php if ($page['sidebar_first']): ?>
          <aside id="sidebar" class="col-xs-12 col-sm-3" role="complementary">
            <?php print render($page['sidebar_first']); ?>
          </aside> 
        <?php endif; ?>
		
        <div class="col-xs-12 col-sm-<?php print $main_col; ?>">
          <section id="content" role="main" class="clearfix">
			<?php if ($breadcrumb): ?>
		      <div id="breadcrumb"><?php print $breadcrumb; ?></div>
		    <?php endif; ?>            
			<?php print $messages; ?>
            <?php if ($page['top_content']): ?><div id="top_content"><?php print render($page['top_content']); ?></div><?php endif; ?>
            <div id="content-wrap">
              <?php print render($title_prefix); ?>
              <?php if ($title): ?><h1 class="page-title"><?php print $title; ?></h1><?php endif; ?>
              <?php print render($title_suffix); ?>
              <?php if ($tabs): ?>
		        <div class="tabs">
		          <?php print render($tabs); ?>
		        </div>
		      <?php endif; ?>
              <?php print render($page['help']); ?>
              <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
              <?php print render($page['content']); ?>
            </div>
          </section>
        </div>
		
        <?php if ($page['sidebar_second']): ?>
          <aside id="sidebar" class="col-xs-12 col-sm-3" role="complementary">
            <?php print render($page['sidebar_second']); ?>
          </aside> 
        <?php endif; ?>
		
      </div>
    </div>
  </div>

  
  <?php if($page['bottom_first'] || $page['bottom_second'] || $page['bottom_third'] || $page['bottom_fourth']): ?>
    <?php $bottom_col = ( 12 / ( (bool) $page['bottom_first'] + (bool) $page['bottom_second'] + (bool) $page['bottom_third'] + (bool) $page['bottom_fourth'] ) ); ?>
    <div id="bottom-columns">
	  <div class="container">
	    <div class="row">
		  <?php if($page['bottom_first']): ?>
		    <div class="col-xs-12 col-sm-<?php print $bottom_col; ?>">
			  <?php print render($page['bottom_first']); ?>
		    </div>
		  <?php endif; ?>
		  <?php if($page['bottom_second']): ?>
		    <div class="col-xs-12 col-sm-<?php print $bottom_col; ?>">
			  <?php print render($page['bottom_second']); ?>
			</div>
		  <?php endif; ?>
		  <?php if($page['bottom_third']): ?>
		    <div class="col-xs-12 col-sm-<?php print $bottom_col; ?>">
			  <?php print render($page['bottom_third']); ?>
			</div>
		  <?php endif; ?>
		  <?php if($page['bottom_fourth']): ?>
			<div class="col-xs-12 col-sm-<?php print $bottom_col; ?>">
			  <?php print render($page['bottom_fourth']); ?>
			</div>
		  <?php endif; ?>
		</div>
	  </div>
	</div>
  <?php endif; ?>  
  
  
  <footer>
    <div class="container">
      <?php if($page['footer_first'] || $page['footer_second'] || $page['footer_third'] || $page['footer_fourth']): ?>
		<?php $footer_col = ( 12 / ( (bool) $page['footer_first'] + (bool) $page['footer_second'] + (bool) $page['footer_third'] + (bool) $page['footer_fourth'] ) ); ?>
		  <div id="footer-columns">
			<div class="row">
			  <?php if($page['footer_first']): ?>
			    <div class="col-xs-12 col-sm-<?php print $footer_col; ?>">
				  <?php print render($page['footer_first']); ?>
				</div>
			  <?php endif; ?>
			  <?php if($page['footer_second']): ?>
				<div class="col-xs-12 col-sm-<?php print $footer_col; ?>">
			      <?php print render($page['footer_second']); ?>
				</div>
			  <?php endif; ?>
			  <?php if($page['footer_third']): ?>
				<div class="col-xs-12 col-sm-<?php print $footer_col; ?>">
				  <?php print render($page['footer_third']); ?>
				</div>
			  <?php endif; ?>
		      <?php if($page['footer_fourth']): ?>
				<div class="col-xs-12 col-sm-<?php print $footer_col; ?>">
				  <?php print render($page['footer_fourth']); ?>
				</div>
			  <?php endif; ?>
			</div>
		  </div>
		<?php endif; ?>  

        <div class="row">
          <div class="col-xs-12">
            <?php if($page['footer']) : ?><?php print render($page['footer']); ?><?php endif; ?>
			<?php print t('Copyright'); ?> &copy; <?php echo date("Y"); ?>. <a href="<?php print $front_page; ?>"><?php print $site_name; ?></a> <?php print t('Theme by'); ?>  <a href="http://www.kattio.ru" target="_blank">Katerina</a>
          </div>
        </div>
      </div>
    </footer>
  